============
Installation
============

From PyPi
^^^^^^^^^^

.. code-block:: bash

    $ pip install Jobber

or

.. code-block:: bash

    $ pip install Jobber
    $ pip install --user Jobber

From GitLab
^^^^^^^^^^^^

.. code-block:: bash

    $ git clone ssh://git@git.scicore.unibas.ch:2222/AnnotationPipelines/Jobber.git
    $ cd Jobber
    $ python setup.py install --user



